@@ -87,18 +87,17 @@ from web3.exceptions import (
 )
 from web3.types import (
     BlockIdentifier,
+    CallOverrideParams,
     RPCEndpoint,
     RPCResponse,
     TReturn,
+    TxParams,
     _Hash32,
 )
 
 if TYPE_CHECKING:
     from web3 import Web3  # noqa: F401
-    from web3.module import (  # noqa: F401
-        Module,
-        ModuleV2,
-    )
+    from web3.module import Module  # noqa: F401
     from web3.eth import Eth  # noqa: F401
 
 
@@ -315,6 +314,25 @@ transaction_param_formatter = compose(
 )
 
 
+call_without_override: Callable[
+    [Tuple[TxParams, BlockIdentifier]],
+    Tuple[Dict[str, Any], int]
+]
+call_without_override = apply_formatters_to_sequence([
+    transaction_param_formatter,
+    to_hex_if_integer,
+])
+call_with_override: Callable[
+    [Tuple[TxParams, BlockIdentifier, CallOverrideParams]],
+    Tuple[Dict[str, Any], int, Dict[str, Any]],
+]
+call_with_override = apply_formatters_to_sequence([
+    transaction_param_formatter,
+    to_hex_if_integer,
+    lambda x: x,
+])
+
+
 estimate_gas_without_block_id: Callable[[Dict[str, Any]], Dict[str, Any]]
 estimate_gas_without_block_id = apply_formatter_at_index(transaction_param_formatter, 0)
 estimate_gas_with_block_id: Callable[
@@ -374,10 +392,10 @@ PYTHONIC_REQUEST_FORMATTERS: Dict[RPCEndpoint, Callable[..., Any]] = {
     RPC.eth_getUncleByBlockHashAndIndex: apply_formatter_at_index(to_hex_if_integer, 1),
     RPC.eth_newFilter: apply_formatter_at_index(filter_params_formatter, 0),
     RPC.eth_getLogs: apply_formatter_at_index(filter_params_formatter, 0),
-    RPC.eth_call: apply_formatters_to_sequence([
-        transaction_param_formatter,
-        to_hex_if_integer,
-    ]),
+    RPC.eth_call: apply_one_of_formatters((
+        (is_length(2), call_without_override),
+        (is_length(3), call_with_override),
+    )),
     RPC.eth_estimateGas: apply_one_of_formatters((
         (is_length(1), estimate_gas_without_block_id),
         (is_length(2), estimate_gas_with_block_id),
@@ -638,7 +656,7 @@ FILTER_RESULT_FORMATTERS: Dict[RPCEndpoint, Callable[..., Any]] = {
 @to_tuple
 def apply_module_to_formatters(
         formatters: Tuple[Callable[..., TReturn]],
-        module: Union["Module", "ModuleV2"],
+        module: "Module",
         method_name: Union[RPCEndpoint, Callable[..., RPCEndpoint]],
 ) -> Iterable[Callable[..., TReturn]]:
     for f in formatters:
@@ -647,7 +665,7 @@ def apply_module_to_formatters(
 
 def get_result_formatters(
     method_name: Union[RPCEndpoint, Callable[..., RPCEndpoint]],
-    module: Union["Module", "ModuleV2"],
+    module: "Module",
 ) -> Dict[str, Callable[..., Any]]:
     formatters = combine_formatters(
         (PYTHONIC_RESULT_FORMATTERS,),
